=================
API Documentation
=================

uriregistry
===========

.. automodule:: uriregistry
   :members:
   :private-members:

Models module
-------------

.. automodule:: uriregistry.models
   :members:
   :private-members:

Registry module
---------------

.. automodule:: uriregistry.registry
   :members:
   :private-members:

Views module
------------

.. automodule:: uriregistry.views
   :members:
   :private-members:

Utils module
------------

.. automodule:: uriregistry.utils
   :members:
   :private-members:


pyramid_urireferencer
=====================

.. automodule:: pyramid_urireferencer
   :members:
   :private-members:

Models module
-------------

.. automodule:: pyramid_urireferencer.models
   :members:
   :private-members:

Protected resources module
--------------------------

.. automodule:: pyramid_urireferencer.protected_resources
   :members:
   :private-members:

Referencer module
-----------------

.. automodule:: pyramid_urireferencer.referencer
   :members:
   :private-members:

Rendererers module
------------------

.. automodule:: pyramid_urireferencer.renderers
   :members:
   :private-members:

Views module
------------

.. automodule:: pyramid_urireferencer.views
   :members:
   :private-members:
